pub struct PanickingNoOpClient { /* private fields */ }Expand description
A variant of NoOpClient that panics instead of returning an error.
This is useful during development to catch unexpected HTTP requests with a clear stack trace showing exactly where the request originated.
Implementations