pub struct NoOpClient { /* private fields */ }Expand description
A no-op HTTP client that always fails with an error.
This client is useful for testing VCR in replay mode to ensure that no real HTTP requests are made. Any attempt to send a request will result in an error.
Usage
use http_client_vcr::{VcrClient, VcrMode, NoOpClient};
use http_client::HttpClient;
use http_types::{Request, Method, Url};
// Ensure no real HTTP requests can be made
let vcr_client = VcrClient::builder("fixtures/test.yaml")
.inner_client(Box::new(NoOpClient::new()))
.mode(VcrMode::Replay) // Only replay from cassette
.build()
.await?;
// This will work if the request is in the cassette
let request = Request::new(Method::Get, Url::parse("https://example.com")?);
let response = vcr_client.send(request).await?;
// If not in cassette, VCR will return an error before reaching NoOpClient
// If somehow a request reaches NoOpClient, it will panic with a clear messageImplementations
Sourceimpl NoOpClient
impl NoOpClient
Sourcepub fn with_message(message: impl Into<String>) -> Self
pub fn with_message(message: impl Into<String>) -> Self
Create a NoOpClient with a custom error message.
Sourcepub fn panicking() -> PanickingNoOpClient
pub fn panicking() -> PanickingNoOpClient
Create a NoOpClient that panics instead of returning an error. This is useful for catching unexpected HTTP requests during development.