VcrClient

Struct VcrClient 

pub struct VcrClient { /* private fields */ }

Implementations

Source

impl VcrClient

pub fn new( inner: Box<dyn HttpClient>, mode: VcrMode, cassette: Cassette, ) -> Self

pub fn set_mode(&mut self, mode: VcrMode)

pub fn set_matcher(&mut self, matcher: Box<dyn RequestMatcher>)

pub fn set_filter_chain(&mut self, filter_chain: FilterChain)

pub fn add_filter(&mut self, filter: Box<dyn Filter>)

pub async fn save_cassette(&self) -> Result<(), Error>

pub async fn apply_filters_to_cassette(&self) -> Result<(), Error>

Apply filters to all interactions in the cassette This modifies the cassette in-place by applying the configured filter chain to all interactions

pub async fn filter_and_save_cassette(&self) -> Result<(), Error>

Apply filters to all interactions in the cassette and save the filtered version

pub fn builder<P: Into<PathBuf>>(cassette_path: P) -> VcrClientBuilder